use 5.014;

use strict;
use warnings;

use Test::More;

=name

Data::Object::Float::Func

=abstract

Functions for Float Data

=synopsis

  use Data::Object::Float::Func;

=inherits

Data::Object::Func

=libraries

Data::Object::Library

=description

Data::Object::Float::Func is an abstract base class for function classes in the
Data::Object::Float::Func space.

=cut

use_ok "Data::Object::Float::Func";

ok 1 and done_testing;
