use strict;
use warnings;
use Test::More;

use_ok 'Data::Object::Hash::Func';
use_ok 'Data::Object::Hash::Func::Clear';
use_ok 'Data::Object::Hash::Func::Count';
use_ok 'Data::Object::Hash::Func::Defined';
use_ok 'Data::Object::Hash::Func::Delete';
use_ok 'Data::Object::Hash::Func::Each';
use_ok 'Data::Object::Hash::Func::EachKey';
use_ok 'Data::Object::Hash::Func::EachNValues';
use_ok 'Data::Object::Hash::Func::EachValue';
use_ok 'Data::Object::Hash::Func::Empty';
use_ok 'Data::Object::Hash::Func::Eq';
use_ok 'Data::Object::Hash::Func::Exists';
use_ok 'Data::Object::Hash::Func::FilterExclude';
use_ok 'Data::Object::Hash::Func::FilterInclude';
use_ok 'Data::Object::Hash::Func::Fold';
use_ok 'Data::Object::Hash::Func::Ge';
use_ok 'Data::Object::Hash::Func::Get';
use_ok 'Data::Object::Hash::Func::Grep';
use_ok 'Data::Object::Hash::Func::Gt';
use_ok 'Data::Object::Hash::Func::Head';
use_ok 'Data::Object::Hash::Func::Invert';
use_ok 'Data::Object::Hash::Func::Iterator';
use_ok 'Data::Object::Hash::Func::Join';
use_ok 'Data::Object::Hash::Func::Keys';
use_ok 'Data::Object::Hash::Func::Le';
use_ok 'Data::Object::Hash::Func::Length';
use_ok 'Data::Object::Hash::Func::List';
use_ok 'Data::Object::Hash::Func::Lookup';
use_ok 'Data::Object::Hash::Func::Lt';
use_ok 'Data::Object::Hash::Func::Map';
use_ok 'Data::Object::Hash::Func::Merge';
use_ok 'Data::Object::Hash::Func::Ne';
use_ok 'Data::Object::Hash::Func::Pairs';
use_ok 'Data::Object::Hash::Func::Reset';
use_ok 'Data::Object::Hash::Func::Reverse';
use_ok 'Data::Object::Hash::Func::Set';
use_ok 'Data::Object::Hash::Func::Slice';
use_ok 'Data::Object::Hash::Func::Sort';
use_ok 'Data::Object::Hash::Func::Tail';
use_ok 'Data::Object::Hash::Func::Unfold';
use_ok 'Data::Object::Hash::Func::Values';

ok 1 and done_testing;
